Bootstrap Components › Form — Stisla

# Form

## Forms

Examples and usage guidelines for form control styles, layout options, and custom components for creating a wide variety of forms.

#### HTML5 Form Basic

Note! Not all browsers support HTML5 type input.
Text
Select
Select Multiple
Textarea
Checkbox
Checkbox 1
Checkbox 2
Color
Date
Datetime Local
Email
File
Month
Password
Radio
Radio 1
Radio 2
Range
Search
Tel
Time
Url
Week

#### Inline Forms

Name Username

#### Help Text

Password Your password must be 8-20 characters long, contain letters and numbers, and must not contain spaces, special characters, or emoji.
Password Must be 8-20 characters long.

#### Custom Forms #2

Select
Choose One
File Browser
Choose file

#### Input Group Text

@
.com
$
.00

#### Input Group #2

Multiple Addons
First and last name
Button
Select With Button
Select, Button & Input

#### Sizing

Text
Text `.form-control-sm`
Text
Text `.form-control-lg`
Select
Select `.form-control-sm`
Select
Select `.form-control-lg`

#### Disabled & Read Only

Text
Readonly
Readonly Plain Text
Select
Select Disabled
Checkbox
Disabled checkbox
Radio
Disabled radio

#### Inline

Inline Checkbox
1
2
3 (disabled)
Inline Radio
1
2
3 (disabled)

#### Horizontal Form

Email
Password
Address
Address 2
City
State
Zip
Check me out

#### Horizontal Form

Email
Password
Radios
First radio
Second radio
Third disabled radio
Checkbox
Example checkbox

#### Custom Forms

Checkbox
Check this custom checkbox
Checkbox
Toggle this custom radio
Or toggle this other custom radio
Inline
Toggle this custom radio
Or toggle this other custom radio
Disabled
Check this custom checkbox
Toggle this custom radio

#### Learn More

All the above form elements are the default of bootstrap and you can learn them on the official documentation provided by Bootstrap.

Learn more